==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/content/kinetics/deployer/DeployerFabricFakePlayer.java <==
package com.zurrtum.create.content.kinetics.deployer;

import com.mojang.authlib.GameProfile;
import net.fabricmc.fabric.api.entity.FakePlayer;
import net.minecraft.class_1293;
import net.minecraft.class_1304;
import net.minecraft.class_1799;
import net.minecraft.class_2338;
import net.minecraft.class_243;
import net.minecraft.class_2561;
import net.minecraft.class_3218;
import net.minecraft.class_3225;
import net.minecraft.class_4048;
import net.minecraft.class_4050;
import org.apache.commons.lang3.tuple.Pair;

public class DeployerFabricFakePlayer extends FakePlayer implements DeployerPlayer {
    private Pair<class_2338, Float> blockBreakingProgress;
    private class_1799 spawnedItemEffects;
    public boolean placedTracks;
    public boolean onMinecartContraption;

    protected DeployerFabricFakePlayer(class_3218 world, GameProfile profile) {
        super(world, profile);
    }

    @Override
    public class_3225 getInteractionManager() {
        return field_13974;
    }

    @Override
    public Pair<class_2338, Float> getBlockBreakingProgress() {
        return blockBreakingProgress;
    }

    @Override
    public void setBlockBreakingProgress(Pair<class_2338, Float> blockBreakingProgress) {
        this.blockBreakingProgress = blockBreakingProgress;
    }

    @Override
    public class_1799 getSpawnedItemEffects() {
        return spawnedItemEffects;
    }

    @Override
    public void setSpawnedItemEffects(class_1799 spawnedItemEffects) {
        this.spawnedItemEffects = spawnedItemEffects;
    }

    @Override
    public boolean getPlacedTracks() {
        return placedTracks;
    }

    @Override
    public void setPlacedTracks(boolean placedTracks) {
        this.placedTracks = placedTracks;
    }

    @Override
    public boolean isOnMinecartContraption() {
        return onMinecartContraption;
    }

    @Override
    public void setOnMinecartContraption(boolean onMinecartContraption) {
        this.onMinecartContraption = onMinecartContraption;
    }

    @Override
    public class_2561 method_5476() {
        return class_2561.method_43471("create.block.deployer.damage_source_name");
    }

    @Override
    public class_4048 method_55694(class_4050 pose) {
        return super.method_55694(pose).method_55685(0);
    }

    @Override
    public class_243 method_19538() {
        class_243 pos = super.method_19538();
        return new class_243(pos.field_1352, pos.field_1351, pos.field_1350);
    }

    @Override
    public float method_7279() {
        return 1 / 64f;
    }

    @Override
    public boolean method_7332(boolean ignoreHunger) {
        return false;
    }

    @Override
    public boolean method_6049(class_1293 effect) {
        return false;
    }

    @Override
    public boolean method_44201(class_1304 slot) {
        return false;
    }

    @Override
    public void method_5650(class_5529 reason) {
        class_3218 world = method_51469();
        if (blockBreakingProgress != null && !world.field_9236)
            world.method_8517(method_5628(), blockBreakingProgress.getKey(), -1);
        super.method_5650(reason);
    }
}

==> create-fly-1.21.10-6.0.8-3-sources.jar: com/zurrtum/create/content/kinetics/deployer/DeployerFabricFakePlayer.java <==
package com.zurrtum.create.content.kinetics.deployer;

import com.mojang.authlib.GameProfile;
import net.fabricmc.fabric.api.entity.FakePlayer;
import net.minecraft.class_1293;
import net.minecraft.class_1304;
import net.minecraft.class_1799;
import net.minecraft.class_1934;
import net.minecraft.class_2338;
import net.minecraft.class_243;
import net.minecraft.class_2561;
import net.minecraft.class_3218;
import net.minecraft.class_3225;
import net.minecraft.class_4048;
import net.minecraft.class_4050;
import org.apache.commons.lang3.tuple.Pair;

public class DeployerFabricFakePlayer extends FakePlayer implements DeployerPlayer {
    private Pair<class_2338, Float> blockBreakingProgress;
    private class_1799 spawnedItemEffects;
    public boolean placedTracks;
    public boolean onMinecartContraption;

    protected DeployerFabricFakePlayer(class_3218 world, GameProfile profile) {
        super(world, profile);
        field_13974.method_14261(class_1934.field_9215, null);
    }

    @Override
    public class_3225 getInteractionManager() {
        return field_13974;
    }

    @Override
    public Pair<class_2338, Float> getBlockBreakingProgress() {
        return blockBreakingProgress;
    }

    @Override
    public void setBlockBreakingProgress(Pair<class_2338, Float> blockBreakingProgress) {
        this.blockBreakingProgress = blockBreakingProgress;
    }

    @Override
    public class_1799 getSpawnedItemEffects() {
        return spawnedItemEffects;
    }

    @Override
    public void setSpawnedItemEffects(class_1799 spawnedItemEffects) {
        this.spawnedItemEffects = spawnedItemEffects;
    }

    @Override
    public boolean getPlacedTracks() {
        return placedTracks;
    }

    @Override
    public void setPlacedTracks(boolean placedTracks) {
        this.placedTracks = placedTracks;
    }

    @Override
    public boolean isOnMinecartContraption() {
        return onMinecartContraption;
    }

    @Override
    public void setOnMinecartContraption(boolean onMinecartContraption) {
        this.onMinecartContraption = onMinecartContraption;
    }

    @Override
    public class_2561 method_5476() {
        return class_2561.method_43471("create.block.deployer.damage_source_name");
    }

    @Override
    public class_4048 method_55694(class_4050 pose) {
        return super.method_55694(pose).method_55685(0);
    }

    @Override
    public class_243 method_73189() {
        class_243 pos = super.method_73189();
        return new class_243(pos.field_1352, pos.field_1351, pos.field_1350);
    }

    @Override
    public float method_7279() {
        return 1 / 64f;
    }

    @Override
    public boolean method_7332(boolean ignoreHunger) {
        return false;
    }

    @Override
    public boolean method_6049(class_1293 effect) {
        return false;
    }

    @Override
    public boolean method_44201(class_1304 slot) {
        return false;
    }

    @Override
    public void method_5650(class_5529 reason) {
        class_3218 world = method_51469();
        if (blockBreakingProgress != null && !world.method_8608())
            world.method_8517(method_5628(), blockBreakingProgress.getKey(), -1);
        super.method_5650(reason);
    }
}
